import { defineStore } from 'pinia';
import projectsApi from '@Api/projects';
import projectData from '@Data/projects.json';
import { Project, CreateProjectForm } from '@Interfaces/Project';


export const useProjectStore = defineStore('project', {
    state: () => ({
        defaultProject: {
            name: '',
            owner: '',
            lifecycle: '',
            entity_type: '',
        } as Project,
        project: null as Project| null,
        projects: projectData as unknown as Project[],
    }),
    getters: {
        getDefaultProject: (state) => state.defaultProject,
        getProject: (state) => state.project,
        getProjectById: (state) => (id: number) => {
            return state.projects.find(project => project.id == id) || null;
        },
        getProjects: (state) => state.projects,
    },

    actions: {
        createProject(form: CreateProjectForm) {
            this.projects.push({ ...form, id: this.projects.length + 1 });
            //projectsApi.createProject(form);
        },
        initializeProject() {
            this.project = { ...this.defaultProject };
        },
        initializeProjects() {
            this.projects = projectData;
        },
        resetProjectForm() {
            this.project = { ...this.defaultProject };
        }
    },
});
