type Status = "action-required" | "completed" | "under-review" | string;

export function getStatusClass(status: Status): string {
  const classes: Record<Status, string> = {
    "action-required": "p-tag-warn",
    completed: "p-tag-success",
    "under-review": "p-tag-info",
  };
  return classes[status] || "p-tag-default";
}

export function getStatusIcon(status: Status): string {
  const icons: Record<Status, string> = {
    "action-required": "pi pi-exclamation-triangle",
    completed: "pi pi-check",
    "under-review": "pi pi-hourglass",
  };
  return icons[status] || "pi pi-info-circle";
}

export function getStatusSeverity(status: Status): string {
  const severities: Record<Status, string> = {
    "action-required": "warn",
    completed: "success",
    "under-review": "info",
  };
  return severities[status] || "default";
}

export function formatStatus(status: string): string {
  return status
    .split("-")
    .map((word) => word.charAt(0).toUpperCase() + word.slice(1))
    .join(" ");
}

export function getIconPath(tech: string): string {
  return `/images/techicons/${tech}Light.svg`;
}
