import './bootstrap';

import { createInertiaApp } from '@inertiajs/vue3';
import { resolvePageComponent } from 'laravel-vite-plugin/inertia-helpers';
import { createApp, DefineComponent, h } from 'vue';
import { ZiggyVue } from '../../vendor/tightenco/ziggy';
import { plugin as FormKitPlugin, defaultConfig } from '@formkit/vue'
import { createPinia } from 'pinia';
import PrimeVue from 'primevue/config';
import { createVuestic } from "vuestic-ui";
import Aura from '@primevue/themes/aura';

import Vueform from '@vueform/vueform'
import vueformConfig from '../../vueform.config'

import Button from "primevue/button"
import Card from "primevue/card"
import IconField from "primevue/iconfield";
import InputIcon from "primevue/inputicon";
import InputText from "primevue/inputtext";
import Message from 'primevue/message';
import Toast from 'primevue/toast';
import ToastService from 'primevue/toastservice';
import { Form } from '@primevue/forms';
import formkitConfig from '@Root/.formkit.config.js'


import AdminLayout from '@Layouts/AuthLayout.vue'

import 'primeicons/primeicons.css'
import 'vuestic-ui/styles/essential.css';
import 'vuestic-ui/styles/typography.css';
import '@Scss/overrides.scss';

const appName = import.meta.env.VITE_APP_NAME || 'Cassion';

createInertiaApp({
    //title: (title) => `${title} - ${appName}`,
    title: (title) => `${appName}`,
    resolve: async (name) => {
        const page = await resolvePageComponent(
            `./Pages/${name}.vue`,
            import.meta.glob<DefineComponent>('./Pages/**/*.vue'),
        )

        page.default.layout = page.default.layout || AdminLayout

        return page
    },
    setup({ el, App, props, plugin }) {
        const pinia = createPinia();
        createApp({ render: () => h(App, props) })
            .use(plugin)
            .use(pinia)
            .use(ZiggyVue)
            .use(FormKitPlugin, defaultConfig(formkitConfig))
            .use(Vueform, vueformConfig)
            .use(createVuestic())
            .use(PrimeVue, {
                theme: {
                    preset: Aura,
                    options: {
                        darkModeSelector: 'light'
                    }
                }
            })
            .use(ToastService)
            .component('Button', Button)
            .component('Card', Card)
            .component('Form', Form)
            .component('IconField', IconField)
            .component('InputIcon', InputIcon)
            .component('InputText', InputText)
            .component('Message', Message)
            .component('Toast', Toast)
            .mount(el);
    },
    progress: {
        color: '#4B5563',
    },
});
