import { defineConfig } from 'vite';
import path from 'path';
import laravel from 'laravel-vite-plugin';
import vue from '@vitejs/plugin-vue';

export default defineConfig({
    plugins: [
        laravel({
            input: ['resources/scss/app.scss', 'resources/js/app.ts'],
            refresh: true,
        }),
        vue({
            template: {
                transformAssetUrls: {
                    base: null,
                    includeAbsolute: false,
                },
            },
        }),
    ],
    resolve: {
        alias: {
            '~/': path.resolve(__dirname, 'resources/js'),
            '@Api': path.resolve(__dirname, 'resources/js/Api'),
            '@Components': path.resolve(__dirname, 'resources/js/Components'),
            '@Composables': path.resolve(__dirname, 'resources/js/Composables'),
            '@Data': path.resolve(__dirname, 'resources/js/Data'),
            '@Forms': path.resolve(__dirname, 'resources/js/Forms'),
            '@Interfaces': path.resolve(__dirname, 'resources/js/Interfaces'),
            '@Layouts': path.resolve(__dirname, 'resources/js/Layouts'),
            '@Root': path.resolve(__dirname),
            '@Scss': path.resolve(__dirname, 'resources/scss'),
            '@Store': path.resolve(__dirname, 'resources/js/Store'),
            '@Utils': path.resolve(__dirname, 'resources/js/Utils'),
        },
    },
    server: {
        host: true, // Allows Vite to bind to 0.0.0.0
        port: 5173, // Ensure the port matches your Docker setup
        hmr: {
            host: 'localhost',
        },
        watch: {
            usePolling: true, // Useful in Docker environments
        },
    },
});
